from model_utils import Choices

ShippingCarriersEnum = Choices(
    ("Other", "Другое"),
    ("DHL", "DHL Express"),
    ("DHLEKB", "DHL EKB"),
    ("DHLEXPRESS", "DHL Express"),
    ("DHLGlobalMail", "DHL Global Mail"),
    ("UPS", "United Parcel Service"),
    ("USPS", "U.S. Postal Service"),
    ("GENERIC", "Generic"),
)

AllShippingCarriersEnum = Choices(
    ("Other", "Use this code for any carrier not listed here."),
    ("A1CourierServices", "A-1 Courier"),
    ("ABF", "ABF Freight"),
    ("AeroPost", "AeroPost"),
    ("ALLIEDEXPRESS", "Allied Express"),
    ("AMWST", "AMWST"),
    ("AnPost", "An Post"),
    ("APC", "APC Postal Logistics"),
    ("ARAMEX", "Aramex"),
    ("ARVATO", "Arvato"),
    ("ASM", "ASM"),
    ("AustralianAirExpress", "Australian Air Express"),
    ("AustraliaPost", "Australia Post"),
    ("AVRT", "Averitt Express"),
    ("Bartolini", "BRT Bartolini"),
    ("BELGIANPOST", "Belgian Post Group"),
    ("BKNS", "BKNS"),
    ("BluePackage", "Blue Package Delivery"),
    ("BPost", "bpost"),
    ("BusinessPost", "BusinessPost"),
    ("CanPar", "Canpar Courier"),
    ("CENF", "Central Freight Lines"),
    ("CEVA", "CEVA Logistics"),
    ("ChinaPost", "China Post"),
    ("Chronoexpres", "Chronoexpres"),
    ("Chronopost", "Chronopost"),
    ("CHUKOU1", "Chukou1"),
    ("ChunghwaPost", "Chunghwa Post"),
    ("CitiPost", "CitiPost"),
    ("CityLink", "Citylink"),
    ("ClickandQuick", "Click & Quick"),
    ("CNWY", "XPO Logistics (formerly Con-way Freight)"),
    ("ColiposteDomestic", "Coliposte Domestic"),
    ("ColiposteInternational", "Coliposte International"),
    ("Colissimo", "Colissimo"),
    ("CollectPlus", "CollectPlus"),
    ("Correos", "Correos"),
    ("CPC", "CPC Logistics"),
    ("DAIPost", "DAI Post"),
    ("DayandRoss", "Day & Ross"),
    ("DBSchenker", "DB Schenker"),
    ("DeutschePost", "Deutsche Post"),
    ("DHL", "DHL Express"),
    ("DHLEKB", "DHL EKB"),
    ("DHLEXPRESS", "DHL Express"),
    ("DHLGlobalMail", "DHL Global Mail"),
    ("DieSchweizerischePost", "Die Schweizerische Post"),
    ("DPD", "DPD (Dynamic Parcel Distribution)"),
    ("DPXThailand", "DPX Thailand"),
    ("EGO", "E-go"),
    ("Exapaq", "DPD France (formerly Exapaq)"),
    ("Fastway", "Fastway"),
    ("FASTWAYCOURIERS", "Fastway Couriers"),
    ("FedEx", "FedEx"),
    ("FedExSmartPost", "FedEx SmartPost"),
    ("FLYT", "Flyt"),
    ("FLYTExpress", "Flyt Express"),
    ("FlytExpressUSDirectline", "Flyt Express US Direct line"),
    ("FourPX", "4PX"),
    ("FourPXCHINA", "4PX China"),
    ("FourPXExpress", "4PX Express"),
    ("FourPXLTD", "4PX Express Co. Ltd"),
    ("FulfilExpressAccStation", "FulfilExpress-AccStation"),
    ("FulfilExpresseForCity", "FulfilExpress-eForCity"),
    ("FulfilExpressEverydaySource", "FulfilExpress-EverydaySource"),
    ("FulfilExpressiTrimming", "FulfilExpress-iTrimming"),
    ("GLS", "GLS (General Logistics Systems)"),
    ("HDUSA", "MXD Group (formerly Home Direct USA)"),
    ("Hermes", "Hermes Group"),
    ("HongKongPost", "Hong Kong Post"),
    ("HUNTEREXPRESS", "Hunter Express"),
    ("iLoxx", "iloxx eService"),
    ("IndiaPost", "India Post"),
    ("IndonesiaPost", "Indonesia Post"),
    ("Interlink", "Interlink Express"),
    ("InterPost", "InterPost"),
    ("IoInvio", "IoInvio"),
    ("Iparcel", "UPS i-parcel"),
    ("IsraelPost", "Israel Post"),
    ("JapanPost", "Japan Post"),
    ("KIALA", "Kiala (UPS Access Point)"),
    ("KoreaPost", "Korea Post"),
    ("Landmark", "Landmark Global"),
    ("LAPOSTE", "La Poste"),
    ("MALAYSIAPOST", "Malaysia Post"),
    ("MannaFreight", "Manna Distribution Services"),
    ("Metapack", "Metapack"),
    ("MNGTurkey", "MNG Kargo"),
    ("MondialRelay", "Mondial Relay"),
    ("MRW", "MRW"),
    ("MSI", "MSI Transportation"),
    ("Nacex", "Nacex"),
    ("NEMF", "New England Motor Freight"),
    ("ODFL", "Old Dominion Freight Line"),
    ("ONTRACK", "OnTrac Shipping"),
    ("OsterreichischePostAG", "Osterreichische Post"),
    ("Parcelforce", "Parcelforce"),
    ("ParcelPool", "International Bridge Domestic delivery"),
    ("Philpost", "PHLPost (Philippine Postal Corporation)"),
    ("Pilot", "Pilot Freight Services"),
    ("PITD", "PITT OHIO"),
    ("PocztaPolska", "Poczta Polska"),
    ("Pocztex", "Pocztex"),
    ("PosteItaliane", "Poste Italiane"),
    ("POSTITALIANO", "Post Italiano"),
    ("PostNL", "PostNL"),
    ("PostNordNorway", "PostNord"),
    ("Quantium", "Quantium Solutions"),
    ("RETL", "Reddaway"),
    ("RoyalMail", "Royal Mail"),
    ("SAIA", "Saia LTL Freight"),
    ("SDA", "SDA Express Courier"),
    ("SINGAPOREPOST", "Singapore Post"),
    ("Siodemka", "Siodemka (DPD Poland)"),
    ("SioliandFontana", "Sioli & Fontana"),
    ("SkynetMalaysia", "Skynet (Malaysia)"),
    ("SMARTSEND", "Smart Send Courier Service"),
    ("Sogetras", "SGT Corriere Espresso"),
    ("Spediamo", "Spediamo"),
    ("SpeeDee", "Spee-Dee Delivery Service"),
    ("StarTrack", "StarTrack"),
    ("SuntekExpressLTD", "Suntek Express LTD"),
    ("SwissPost", "Swiss Post"),
    ("TELE", "TELE"),
    ("TEMANDO", "Temando (shipping broker)"),
    ("THAILANDPOST", "Thailand Post"),
    ("Toll", "Toll (Japan Post)"),
    ("TPG", "TPG Logistics"),
    ("UBI", "UBI Smart Parcel"),
    ("UKMail", "UK Mail"),
    ("UPS", "United Parcel Service"),
    ("USPS", "U.S. Postal Service"),
    ("USPSCeP", "USPS Commercial ePacket"),
    ("USPSPMI", "USPS Priority Mail International"),
    ("VietnamPost", "Vietnam Post"),
    ("VITR", "Vitran Express"),
    ("Winit", "WIN.IT America"),
    ("WNdirect", "wnDirect"),
    ("WPX", "WPX Delivery Solutions"),
    ("YANWEN", "YANWEN Express"),
    ("Yodel", "Yodel"),
    ("YRC", "YRC Freight"),
)
