MarketplaceToLang = {
    "default": "en-US",
    "EBAY_US": "en-US",
    "EBAY_MOTORS_US": "en-US",
    "EBAY_CA": "en-CA",
    "EBAY_GB": "en-GB",
    "EBAY_AU": "en-AU",
    "EBAY_AT": "de-AT",
    "EBAY_BE_FR": "fr-BE",
    "EBAY_FR": "fr-FR",
    "EBAY_DE": "de-DE",
    "EBAY_IT": "it-IT",
    "EBAY_BE_NL": "nl-BE",
    "EBAY_NL": "nl-NL",
    "EBAY_ES": "es-ES",
    "EBAY_CH": "de-CH",
    "EBAY_TW": "zh-TW",
    "EBAY_CZ": "en-US",  # not defined
    "EBAY_DK": "en-US",  # not defined
    "EBAY_FI": "en-US",  # not defined
    "EBAY_GR": "en-US",  # not defined
    "EBAY_HK": "zh-HK",
    "EBAY_HU": "en-US",  # not defined
    "EBAY_IN": "en-GB",
    "EBAY_ID": "en-US",  # not defined
    "EBAY_IE": "en-IE",
    "EBAY_IL": "en-US",  # not defined
    "EBAY_MY": "en-US",
    "EBAY_NZ": "en-US",  # not defined
    "EBAY_NO": "en-US",  # not defined
    "EBAY_PH": "en-PH",
    "EBAY_PL": "pl-PL",
    "EBAY_PT": "en-US",  # not defined
    "EBAY_PR": "en-US",  # not defined
    "EBAY_RU": "ru-RU",
    "EBAY_SG": "en-US",
    "EBAY_ZA": "en-US",  # not defined
    "EBAY_SE": "en-US",  # not defined
    "EBAY_TH": "th-TH",
    "EBAY_VN": "en-US",
    "EBAY_CN": "en-US",  # not defined
    "EBAY_PE": "en-US",  # not defined
    "EBAY_CA_FR": "fr-CA",
    "EBAY_JP": "en-US",  # not defined
}

MarketplaceToLocale = {
    "default": "en_US",
    "EBAY_US": "en_US",
    "EBAY_MOTORS_US": "en_US",
    "EBAY_CA": "en_CA",
    "EBAY_GB": "en_GB",
    "EBAY_AU": "en_AU",
    "EBAY_AT": "de_AT",
    "EBAY_BE_FR": "fr_BE",
    "EBAY_FR": "fr_FR",
    "EBAY_DE": "de_DE",
    "EBAY_IT": "it_IT",
    "EBAY_BE_NL": "nl_BE",
    "EBAY_NL": "nl_NL",
    "EBAY_ES": "es_ES",
    "EBAY_CH": "de_CH",
    "EBAY_TW": "zh_TW",
    "EBAY_CZ": "en_US",  # not defined
    "EBAY_DK": "en_US",  # not defined
    "EBAY_FI": "en_US",  # not defined
    "EBAY_GR": "en_US",  # not defined
    "EBAY_HK": "zh_HK",
    "EBAY_HU": "en_US",  # not defined
    "EBAY_IN": "en_GB",
    "EBAY_ID": "en_US",  # not defined
    "EBAY_IE": "en_IE",
    "EBAY_IL": "en_US",  # not defined
    "EBAY_MY": "en_US",
    "EBAY_NZ": "en_US",  # not defined
    "EBAY_NO": "en_US",  # not defined
    "EBAY_PH": "en_PH",
    "EBAY_PL": "pl_PL",
    "EBAY_PT": "en_US",  # not defined
    "EBAY_PR": "en_US",  # not defined
    "EBAY_RU": "ru_RU",
    "EBAY_SG": "en_US",
    "EBAY_ZA": "en_US",  # not defined
    "EBAY_SE": "en_US",  # not defined
    "EBAY_TH": "th_TH",
    "EBAY_VN": "en_US",
    "EBAY_CN": "en_US",  # not defined
    "EBAY_PE": "en_US",  # not defined
    "EBAY_CA_FR": "fr_CA",
    "EBAY_JP": "en_US",  # not defined
}
